@@ -24,6 +24,7 @@ sub virtual {
     my($self, $uri, $r) = @_;
     $r ||= Apache->request;
     my $subr = $r->lookup_uri($uri);
+    $subr->header_in("Content-length" => "0");
     $subr->run;
     return $subr->status;
 }
@@ -78,6 +79,6 @@ perl(1), mod_perl(3), mod_include
 
 =head1 AUTHOR
 
-Doug MacEachern <dougm@osf.org>
+Doug MacEachern
 
 
