@@ -1,5 +1,6 @@
+#!perl
 use strict;
-use Apache::test;
+use Apache::testold;
 
 my $r = shift;
 $r->send_http_header('text/plain');
@@ -9,7 +10,10 @@ unless(have_module "Apache::File") {
     return;
 }
 
+# untaint $ENV{PATH}
+$ENV{'PATH'} = '/bin:/usr/bin';
 require Apache::File;
+
 print "1..6\n";
 my $fh = Apache::File->new;
 my $i = 0;
